@@ -1,12 +1,10 @@
-import cStringIO as StringIO
-
+from django.conf import settings
 from django.core.exceptions import ImproperlyConfigured
 from django.core.management import call_command
 from django.http import HttpResponse
-from django.test import TestCase
-from django.conf import settings
-
-from .test_utils import override_settings, RequestFactory
+from django.test import TestCase, RequestFactory
+from django.test.utils import override_settings
+from django.utils.six import StringIO
 
 
 
@@ -25,7 +23,7 @@ class SecurityMiddlewareTest(TestCase):
     def response(self, *args, **kwargs):
         headers = kwargs.pop("headers", {})
         response = HttpResponse(*args, **kwargs)
-        for k, v in headers.iteritems():
+        for k, v in headers.items():
             response[k] = v
         return response
 
@@ -388,8 +386,8 @@ class RunChecksTest(TestCase):
 
 class CheckSettingsCommandTest(TestCase):
     def call(self, **options):
-        stdout = options.setdefault("stdout", StringIO.StringIO())
-        stderr = options.setdefault("stderr", StringIO.StringIO())
+        stdout = options.setdefault("stdout", StringIO())
+        stderr = options.setdefault("stderr", StringIO())
 
         call_command("checksecure", **options)
 
